==> flink-1.14.2-src.tgz: flink-1.14.2/flink-table/flink-table-common/src/test/java/org/apache/flink/table/utils/LegacyRowResource.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.table.utils;

import org.apache.flink.types.Row;
import org.apache.flink.types.RowUtils;

import org.junit.rules.ExternalResource;

/**
 * Enables the old behavior of {@link Row#toString()} for legacy tests.
 *
 * <p>It ignores the changes applied in FLINK-16998 and FLINK-19981.
 */
public class LegacyRowResource extends ExternalResource {

    public static final LegacyRowResource INSTANCE = new LegacyRowResource();

    private LegacyRowResource() {
        // singleton
    }

    @Override
    protected void before() {
        RowUtils.USE_LEGACY_TO_STRING = true;
    }

    @Override
    protected void after() {
        RowUtils.USE_LEGACY_TO_STRING = false;
    }
}

==> flink-1.19.3-src.tgz: flink-1.19.3/flink-table/flink-table-common/src/test/java/org/apache/flink/table/utils/LegacyRowResource.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.table.utils;

import org.apache.flink.types.Row;
import org.apache.flink.types.RowUtils;

import org.junit.rules.ExternalResource;

/**
 * Enables the old behavior of {@link Row#toString()} for legacy tests.
 *
 * <p>It ignores the changes applied in FLINK-16998 and FLINK-19981.
 */
public class LegacyRowResource extends ExternalResource {

    public static final LegacyRowResource INSTANCE = new LegacyRowResource();

    private LegacyRowResource() {
        // singleton
    }

    @Override
    public void before() {
        RowUtils.USE_LEGACY_TO_STRING = true;
    }

    @Override
    public void after() {
        RowUtils.USE_LEGACY_TO_STRING = false;
    }
}
